declare const _exports: ({
    fingerprint: {
        manufId: number;
        endpoints: {
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: number[];
        }[];
    }[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: undefined[];
    toZigbee: undefined[];
    exposes: undefined[];
} | {
    zigbeeModel: string[];
    fingerprint: {
        manufId: number;
        endpoints: {
            ID: number;
            profileID: number;
            deviceID: number;
            inputClusters: number[];
            outputClusters: number[];
        }[];
    }[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            state: string;
        };
    }[];
    toZigbee: {
        key: string[];
        options: exposes.Binary[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state: {
                position: any;
            };
            readAfterWriteTime: number;
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    exposes: exposes.Cover[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
} | {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: undefined[];
    toZigbee: undefined[];
    exposes: undefined[];
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=profalux.d.ts.map