declare const _exports: {
    zigbeeModel: string[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: ({
        cluster: string;
        type: string[];
        options: exposes.Binary[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {};
    } | {
        cluster: string;
        type: string;
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            action: any;
        };
    } | {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            inlet_temperature: any;
            inletTemperature: any;
            status: any;
            line_frequency: any;
            linefrequency: any;
            power: any;
            voltage: any;
            current: any;
            reactive_power: any;
            reactivepower: any;
            energy_consumed: any;
            energyconsumed: any;
            energy: any;
            energy_produced: any;
            energyproduced: any;
            reactive_summation: any;
            reactivesummation: any;
            measure_serial: any;
            measureserial: any;
        };
    } | FromZigbeeConverter)[];
    exposes: (exposes.Numeric | exposes.Switch)[];
    toZigbee: {
        key: string[];
        convertSet: (entity: any, key: any, value: any, meta: any) => Promise<{
            state?: undefined;
        } | {
            state: {
                state: any;
            };
        }>;
        convertGet: (entity: any, key: any, meta: any) => Promise<void>;
    }[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
}[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=meazon.d.ts.map