declare const _exports: ({
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    model: string;
    description: string;
    vendor: string;
    extend: {
        meta: {
            applyRedFix: boolean;
            enhancedHue: boolean;
        };
        exposes: any[];
        fromZigbee: any[];
        toZigbee: any[];
    };
} | {
    fingerprint: {
        modelID: string;
        manufacturerName: string;
    }[];
    model: string;
    vendor: string;
    description: string;
    fromZigbee: {
        cluster: string;
        type: string[];
        convert: (model: any, msg: any, publish: any, options: any, meta: any) => {
            battery: any;
            voltage: number;
            battery_low: boolean;
        };
    }[];
    toZigbee: undefined[];
    exposes: exposes.Numeric[];
    configure: (device: any, coordinatorEndpoint: any, logger: any) => Promise<void>;
})[];
export = _exports;
import exposes = require("../lib/exposes");
//# sourceMappingURL=miboxer.d.ts.map